Changelog
=========

0.2.1
-----
* get zenodo and readthedocs working

0.2.0
-----
* Initial version
* working Absorber class
* support multiple pulse times
* much more testing
* better documentation
* add citation
* add github test action
* add github pypi action
* add github citation action
* add copyright stuff
* add ruff support
* use build.os for .readthedocs
* add more badges, tweak colors
